@@ -1,4 +1,6 @@
 import requests
+
+from build.lib.bf_engine.logger import log
 from .base import CallerBase
 from ..config import Config
 from ..entity.enums import QuestionType, QuestionMode, QuestionField
@@ -428,7 +430,7 @@ class QACaller(CallerBase):
             raise BfEngineException(code=code, msg=msg)
         return True
 
-    def delete_corpus(self, question_id, corpus_id):
+    def delete_corpus(self,corpus_id):
         """
         删除语料
         :return:
@@ -436,7 +438,6 @@ class QACaller(CallerBase):
         params = {
             'records': [
                 {
-                    'sq_id': int(question_id),
                     'lq_list': [
                         {
                             'id': int(corpus_id)
@@ -529,6 +530,11 @@ class QACaller(CallerBase):
                        "start_time":"",
                        "end_time":"",
                        "sq_id":int(question_id),
+                       "property":{
+                           "dimension_id_list":[
+
+                           ]
+                       },
                        "tag_id_list": [],
                        "related_sq_id_list":[]
                    }
@@ -592,7 +598,7 @@ class QACaller(CallerBase):
         params = {
             'records': [answer_id]
         }
-        resp = requests.put(self.upload_faq_json_answer_url, headers=self.header, json=params).json()
+        resp = requests.delete(self.upload_faq_json_answer_url, headers=self.header, json=params).json()
         code = int(resp["code"])
         msg = str(resp["message"])
         if code != 0:
@@ -670,8 +676,11 @@ class QACaller(CallerBase):
         similar_sq_result = []
         sq_list = [];
         sq_map = {};
+        log.info(self.module + "开始")
         category_ids_list = self.get_all_sub_list(category_ids)
+        log.info(self.module + "子目录查询完毕")
         self.get_all_sq_under_input_folders(category_ids_list, sq_list, sq_map)
+        log.info(self.module + "sq获取完毕")
         converter = Converter('zh-hans')
         params = {"Text":converter.convert(user_inputs).lower(),'UniqueId':str(random.randint(100,10000)),"IsRelease": online,'Robot':self.app_id}
         print("params: "+str(params))
@@ -682,8 +691,9 @@ class QACaller(CallerBase):
         print(resp['data'])
         if code != 0:
             raise BfEngineException(code=code, msg=msg)
+        log.info(self.module + "预测结果获取完毕")
         for match_sq in resp['data']:
-            if match_sq['sqId'] in sq_list:
+            if 'sqId' in match_sq and match_sq['sqId'] in sq_list:
                ans_list = [];
                match_sq['category_id'] = str(sq_map.get(match_sq['sqId']))
                ans_resp = requests.get(self.upload_faq_json_sq_url + "/" + str(match_sq['sqId'])+"?field=answer", headers=self.header, json={}).json()
@@ -695,8 +705,10 @@ class QACaller(CallerBase):
                    ans_list.append(ans['answer'])
                match_sq['answer'] = ans_list
                similar_sq_result.append(match_sq)
+        log.info(self.module + "结果处理完毕")
         topn = int(max_topn)
         similar_sq_result = sorted(similar_sq_result, key=lambda x: x["score"], reverse=True)[:topn]
+        log.info(self.module + "返回结果")
         return similar_sq_result
 
     def get_all_sq_under_input_folders(self, category_ids_list, sq_list, sq_map):
